import notice from "@/utils/notice/index";

import toast from '@/utils/tool/toast';
import modal from "../../../utils/tool/modal";

export default {

    data(){
        return {
            edit:false,
            loadingStatus:false,
            selectObject:{},
            selectArray:[]
        }
    },

    computed:{
      allSelect(){
          return this.base_flat_data.data.length >0 && this.base_flat_data.data.length === this.selectArray.length;
      },
      total(){
          let price = 0;
          this.selectArray.map((item)=>{

              let index = this.flatIdGETIndex(item);
              if (index !== undefined) {
                  item = this.flatGetData(index);
                  if (item) {
                      price += item.sales_price * item.number;
                  }

              }
          });

          return price.toFixed(2);
      }
    },

    methods:{

        fetch(obj){
            return this.$request({
                url:'product/getCartList',
                token:true,
                page:obj
            }).then((data)=>{
                obj.success(data.data);
                return this.installSelectObject();
            }).catch(obj.fail);
        },

        // 设置安装
        installSelectObject(){
            let selectObject = {};
            this.selectArray.map((item)=>{
                if (this.flatIdGETIndex(item) !== undefined) {
                    selectObject[item] = 1;
                }
            });

            let selectArray = Object.keys(selectObject);
            if (selectArray !== this.selectArray) {
                this.selectArray = selectArray;
                this.selectObject = selectObject;
            }

        },

        triggerEdit(){

            if (this.loadingStatus) return null;

            this.edit = !this.edit;

        },

        triggerSelect(item){

            if (this.loadingStatus) return ;

            if (this.selectObject[item.id] === undefined) {
                this.$set(this.selectObject,item.id,1);
            } else {
                this.$set(this.selectObject,item.id,undefined);
                delete this.selectObject[item.id];
            }

            this.selectArray = Object.keys(this.selectObject);

        },

        triggerInput(item){

           let index = this.flatIdGETIndex(item.item.id);

            item.item.number = item.value;

            this.flatSaveData(index,item.item);

        },

        triggerChange(item){
            this.$request({
                url:'product/editCartInfo',
                data:{
                    cart_id: item.item.id,
                    number: item.value
                },
                token:true
            })
        },

        triggerAllSelect(){

            if (this.allSelect) {
                this.selectObject = {};
                this.selectArray = [];
            } else {
                this.base_flat_data.data.map((item,index)=>{
                    this.selectObject[item.id] = 1;
                });
                this.selectArray = Object.keys(this.selectObject);
            }

        },

        deleteCheckShop(){

            if (this.loadingStatus) return ;
            if (this.selectArray.length <= 0) return toast.info('请选择商品');

            modal.confirm({
                title:'移除确认',
                content:'是否移除选择商品?',
                confirmText:'移除',
                confirmColor:'#FC3538',
                confirm:()=>{
                    return  this.$request({
                        url:'product/delCart',
                        data:{
                            cart_ids: this.selectArray.join(',')
                        },
                        token:true,
                        message:true,
                        failMessage:true,
                        next:({status})=> this.loadingStatus = status
                    }).then((data)=>{

                        if (data.isSuccess) {
                            this.selectArray.map((item)=>{
                                this.flatSplice(this.flatIdGETIndex(item));
                            });
                            this.selectObject = {};
                            this.selectArray = [];
                        }

                    });
                }
            })


        },

        triggerOrder(){
            if (this.loadingStatus) return ;
            if (this.selectArray.length <= 0) return toast.info('请选择商品');

            return this.$router.navigateTo({
                name:'confirm-order',
                params:{
                    is_cart:1,
                    choose_ids: this.selectArray.join(',')
                }
            });


        }

    },

    onShow(){
        if (this.useNoticeItem && this.useNoticeItem.update) {
            this.useNoticeItem = undefined;
            this.selectObject = {};
            this.selectArray = [];
            return this.flatReload(1,true);
        }
    },

    created(){
        notice.on('car',(item)=>{
            console.log(item);
            this.useNoticeItem = item;
        },'car');
    }

}